@@ -1,7 +1,7 @@
 package Module::Install::ForC;
 use strict;
 use warnings;
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 use 5.008000;
 use Module::Install::ForC::Env;
 use Config;              # first released with perl 5.00307
@@ -46,7 +46,7 @@ sub _gen_makefile {
             VERSION      => $self->version,
         }
     );
-    my $mm_params = join("\n", map { $_.'='.($mm->{$_} || '') } qw/FIRST_MAKEFILE MOD_INSTALL ABSPERL ABSPERLRUN VERBINST UNINST PERM_DIR PERL PREOP TRUE TAR RM_F RM_RF NOECHO NOOP INSTALLARCHLIB INSTALL_BASE DIST_CP DIST_DEFAULT POSTOP COMPRESS TARFLAGS TO_UNIX PERLRUN DISTVNAME VERSION NAME ECHO MAKE MV SUFFIX ZIP SHAR FULLPERLRUN FULLPERL/);
+    my $mm_params = join("\n", map { $_.'='.($mm->{$_} || '') } qw/FIRST_MAKEFILE MOD_INSTALL ABSPERL ABSPERLRUN VERBINST UNINST PERM_DIR PERL PREOP TRUE TAR RM_F RM_RF NOECHO NOOP INSTALLARCHLIB INSTALL_BASE DIST_CP DIST_DEFAULT POSTOP COMPRESS TARFLAGS TO_UNIX PERLRUN DISTVNAME VERSION NAME ECHO ECHO_N MAKE MV SUFFIX ZIP SHAR FULLPERLRUN FULLPERL USE_MAKEFILE FIXIN DOC_INSTALL UNINSTALL CP INST_LIB INST_ARCHLIB/);
     (my $make = <<"...") =~ s/^[ ]{4}/\t/gmsx;
 $mm_params
 TEST_VERBOSE=0
@@ -54,13 +54,15 @@ TEST_FILES=@{[ $self->tests || '' ]}
 
 .PHONY: all config static dynamic test linkext manifest blibdirs clean realclean disttest distdir
 
+@{[ $mm->special_targets ]}
+
 all: @Module::Install::ForC::TARGETS
 
 config :: \$(FIRST_MAKEFILE)
     \$(NOECHO) \$(NOOP)
 
 test: @TESTS
-    @{[ $mm->test_via_harness('\$(FULLPERLRUN)', '\$(TEST_FILES)') ]}
+    @{[ $mm->test_via_harness('$(FULLPERLRUN)', '$(TEST_FILES)') ]}
 
 dist: \$(DIST_DEFAULT) \$(FIRST_MAKEFILE)
 
